PyChart
=======

Libreria python per generare semplici grafici tramite la libreria Pillow.

Versione 1.0.5

Installazione
-------------

pip install -i https://test.pypi.org/simple/ PyChart-busnellistefano

Utilizzo
--------

$ python
import pychart

Classi
------

* Mapper

* Graph

* Panel

* Chart
